@@ -169,3 +169,12 @@ def _is_hidden(path):
         if part.startswith("."):
             return True
     return False
+
+
+def _get_base_prefix_compat():
+    """Get base/real prefix, or sys.prefix if there is none."""
+    return getattr(sys, "base_prefix", None) or getattr(sys, "real_prefix", None) or sys.prefix
+
+
+def _in_virtualenv():
+    return "VIRTUAL_ENV" in os.environ or _get_base_prefix_compat() != sys.prefix
\ No newline at end of file
