@@ -22,7 +22,7 @@ class _InsightDataEncoder(json.JSONEncoder):
 
     def default(self, obj):
         if isinstance(obj, InsightData):
-            return (json.dumps({"Payload": obj.data,
-                                "Significance": obj.significance,
-                                "Tags": obj.tags}))
+            return {"Payload": obj.data,
+                    "Significance": obj.significance,
+                    "Tags": obj.tags}
         return json.JSONEncoder.default(self, obj)
